==> haskell-libbf-0.5.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libbf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 libBF
version:              0.5.1
visibility:           public
id:                   libBF-0.5.1-SQurY3buZMKYCMhqGe0mZ
key:                  libBF-0.5.1-SQurY3buZMKYCMhqGe0mZ
license:              MIT
maintainer:           iavor.diatchki@gmail.com
author:               Iavor Diatchki
synopsis:             A binding to the libBF library.
description:
    LibBF is a C library for working with arbitray precision
    IEEE 754 floating point numbers.

category:             Data
abi:                  5a42d1a397eab83987da0e3ec3df7292
exposed:              True
exposed-modules:      LibBF LibBF.Mutable LibBF.Opts
import-dirs:          /usr/lib/ghc-8.10.1/site-local/libBF-0.5.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/libBF-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/libBF-0.5.1
hs-libraries:         HSlibBF-0.5.1-SQurY3buZMKYCMhqGe0mZ
extra-libraries:      bf
depends:              base-4.14.0.0 deepseq-1.4.4.0
haddock-interfaces:   /usr/share/doc/haskell-libbf/html/libBF.haddock
haddock-html:         /usr/share/doc/haskell-libbf/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libbf-0.5.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libbf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 libBF
version:              0.5.1
visibility:           public
id:                   libBF-0.5.1-2TbYKIIhRcKCgpat1Fyudg
key:                  libBF-0.5.1-2TbYKIIhRcKCgpat1Fyudg
license:              MIT
maintainer:           iavor.diatchki@gmail.com
author:               Iavor Diatchki
synopsis:             A binding to the libBF library.
description:
    LibBF is a C library for working with arbitray precision
    IEEE 754 floating point numbers.

category:             Data
abi:                  12d09bacf1ae55585d6238c07d0865fe
exposed:              True
exposed-modules:      LibBF LibBF.Mutable LibBF.Opts
import-dirs:          /usr/lib/ghc-8.10.2/site-local/libBF-0.5.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/libBF-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/libBF-0.5.1
hs-libraries:         HSlibBF-0.5.1-2TbYKIIhRcKCgpat1Fyudg
extra-libraries:      bf
depends:              base-4.14.1.0 deepseq-1.4.4.0
haddock-interfaces:   /usr/share/doc/haskell-libbf/html/libBF.haddock
haddock-html:         /usr/share/doc/haskell-libbf/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
